<?php

namespace Drupal\tacjs\Form\Steps;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Class AddServices.
 *
 * @package Drupal\tacjs\Form
 */
class AddServices extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'tacjs_add_services';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['tacjs.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $form['services'] = [
      '#prefix' => '<p>' . t('Add the services that will be presented to your website users.') . '<br />' . t('More info at the <a href=":install">Installation and configuration guide</a>.', [':install' => Url::fromUri('https://opt-out.ferank.eu/en/install/')->toString()]) . '</p>',
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Add Services'),
      '#title_display' => 'invisible',
    ];

    $types = [
      ['id' => 'other', 'name' => 'Other',],
      ['id' => 'social', 'name' => 'Social',],
      ['id' => 'ads', 'name' => 'Ads',],
      ['id' => 'analytic', 'name' => 'Analytic',],
      ['id' => 'video', 'name' => 'Video',],
      ['id' => 'comment', 'name' => 'Comment',],
      ['id' => 'api', 'name' => 'API',],
      ['id' => 'support', 'name' => 'Support',],
    ];

    foreach ($types as $key => $type) {
      $form['service'][$type['id']] = [
        '#type' => 'details',
        '#title' => $this->t($type['name']),
        '#group' => 'services',
      ];
    }

    $services = [
      ['id' => 'adsensesearchresult', 'name' => 'Google Adsense Search (result)', 'type' => 'ads'],
      ['id' => 'googleadwordsremarketing', 'name' => 'Google Adwords (remarketing)', 'type' => 'ads'],
      ['id' => 'amazon', 'name' => 'Amazon', 'type' => 'ads'],
      ['id' => 'clicmanager', 'name' => 'Clicmanager', 'type' => 'ads'],
      ['id' => 'criteo', 'name' => 'Criteo', 'type' => 'ads'],
      ['id' => 'datingaffiliation', 'name' => 'Dating Affiliation', 'type' => 'ads'],
      ['id' => 'datingaffiliationpopup', 'name' => 'Dating Affiliation (Pop Up)', 'type' => 'ads'],
      ['id' => 'facebookpixel', 'name' => 'Facebook Pixel', 'type' => 'ads'],
      ['id' => 'ferankpub', 'name' => 'FERank (pub)', 'type' => 'ads'],
      ['id' => 'adsense', 'name' => 'Google Adsense', 'type' => 'ads'],
      ['id' => 'googlepartners', 'name' => 'Google Partners Badge', 'type' => 'ads'],
      ['id' => 'adsensesearchform', 'name' => 'Google Adsense Search (form)', 'type' => 'ads'],
      ['id' => 'aduptech_retargeting', 'name' => 'Ad Up Technology (retargeting)', 'type' => 'ads'],
      ['id' => 'googleadwordsconversion', 'name' => 'Google Adwords (conversion)', 'type' => 'ads'],
      ['id' => 'aduptech_conversion', 'name' => 'Ad Up Technology (conversion)', 'type' => 'ads'],
      ['id' => 'aduptech_ads', 'name' => 'Ad Up Technology (ads)', 'type' => 'ads'],
      ['id' => 'prelinker', 'name' => 'Prelinker', 'type' => 'ads'],
      ['id' => 'activecampaign', 'name' => 'Active Campaign', 'type' => 'ads'],
      ['id' => 'pubdirecte', 'name' => 'Pubdirecte', 'type' => 'ads'],
      ['id' => 'adform', 'name' => 'Adform', 'type' => 'ads'],
      ['id' => 'shareasale', 'name' => 'ShareASale', 'type' => 'ads'],
      ['id' => 'twenga', 'name' => 'Twenga', 'type' => 'ads'],
      ['id' => 'bingads', 'name' => 'Bing Ads Universal Event Tracking', 'type' => 'ads'],
      ['id' => 'vshop', 'name' => 'vShop', 'type' => 'ads'],
      ['id' => 'leadforensics', 'name' => 'LeadForensics', 'type' => 'analytic'],
      ['id' => 'alexa', 'name' => 'Alexa', 'type' => 'analytic'],
      ['id' => 'gajs', 'name' => 'Google Analytics (ga.js)', 'type' => 'analytic'],
      ['id' => 'analytics', 'name' => 'Google Analytics (universal)', 'type' => 'analytic'],
      ['id' => 'gtag', 'name' => 'Google Analytics (gtag.js)', 'type' => 'analytic'],
      ['id' => 'etracker', 'name' => 'eTracker', 'type' => 'analytic'],
      ['id' => 'hubspot', 'name' => 'Hubspot', 'type' => 'analytic'],
      ['id' => 'mautic', 'name' => 'Mautic', 'type' => 'analytic'],
      ['id' => 'microsoftcampaignanalytics', 'name' => 'Microsoft Campaign Analytics', 'type' => 'analytic'],
      ['id' => 'xiti_smarttag', 'name' => 'Xiti (SmartTag)', 'type' => 'analytic'],
      ['id' => 'ferank', 'name' => 'FERank', 'type' => 'analytic'],
      ['id' => 'crazyegg', 'name' => 'Crazy Egg', 'type' => 'analytic'],
      ['id' => 'getplus', 'name' => 'Get+', 'type' => 'analytic'],
      ['id' => 'webmecanik', 'name' => 'Webmecanik', 'type' => 'analytic'],
      ['id' => 'multiplegtag', 'name' => 'Google Analytics (gtag.js)', 'type' => 'analytic'],
      ['id' => 'statcounter', 'name' => 'StatCounter', 'type' => 'analytic'],
      ['id' => 'getquanty', 'name' => 'GetQuanty', 'type' => 'analytic'],
      ['id' => 'emolytics', 'name' => 'Emolytics', 'type' => 'analytic'],
      ['id' => 'hotjar', 'name' => 'Hotjar', 'type' => 'analytic'],
      ['id' => 'visualrevenue', 'name' => 'VisualRevenue', 'type' => 'analytic'],
      ['id' => 'clicky', 'name' => 'Clicky', 'type' => 'analytic'],
      ['id' => 'wysistat', 'name' => 'Wysistat', 'type' => 'analytic'],
      ['id' => 'xiti', 'name' => 'Xiti', 'type' => 'analytic'],
      ['id' => 'atinternet', 'name' => 'AT Internet', 'type' => 'analytic'],
      ['id' => 'matomo', 'name' => 'Matomo (formerly known as Piwik)', 'type' => 'analytic'],
      ['id' => 'koban', 'name' => 'Koban', 'type' => 'analytic'],
      ['id' => 'googletagmanager', 'name' => 'Google Tag Manager', 'type' => 'api'],
      ['id' => 'googlemaps', 'name' => 'Google Maps', 'type' => 'api'],
      ['id' => 'jsapi', 'name' => 'Google jsapi', 'type' => 'api'],
      ['id' => 'twitterwidgetsapi', 'name' => 'Twitter Widgets API', 'type' => 'api'],
      ['id' => 'recaptcha', 'name' => 'reCAPTCHA', 'type' => 'api'],
      ['id' => 'googlemapssearch', 'name' => 'Google Maps Search API', 'type' => 'api'],
      ['id' => 'googlemapsembed', 'name' => 'Google Maps Embed', 'type' => 'api'],
      ['id' => 'timelinejs', 'name' => 'Timeline JS', 'type' => 'api'],
      ['id' => 'tagcommander', 'name' => 'TagCommander', 'type' => 'api'],
      ['id' => 'typekit', 'name' => 'Typekit (adobe)', 'type' => 'api'],
      ['id' => 'facebookcomment', 'name' => 'Facebook (commentaire)', 'type' => 'comment'],
      ['id' => 'disqus', 'name' => 'Disqus', 'type' => 'comment'],
      ['id' => 'matterport', 'name' => 'Matterport', 'type' => 'other'],
      ['id' => 'issuu', 'name' => 'Issuu', 'type' => 'other'],
      ['id' => 'iframe', 'name' => 'Web content', 'type' => 'other'],
      ['id' => 'twittertimeline', 'name' => 'Twitter (timelines)', 'type' => 'social'],
      ['id' => 'ekomi', 'name' => 'eKomi', 'type' => 'social'],
      ['id' => 'linkedin', 'name' => 'Linkedin', 'type' => 'social'],
      ['id' => 'gplus', 'name' => 'Google+', 'type' => 'social'],
      ['id' => 'shareaholic', 'name' => 'Shareaholic', 'type' => 'social'],
      ['id' => 'gplusbadge', 'name' => 'Google+ (badge)', 'type' => 'social'],
      ['id' => 'sharethis', 'name' => 'ShareThis', 'type' => 'social'],
      ['id' => 'facebook', 'name' => 'Facebook', 'type' => 'social'],
      ['id' => 'addthis', 'name' => 'AddThis', 'type' => 'social'],
      ['id' => 'facebooklikebox', 'name' => 'Facebook (like box)', 'type' => 'social'],
      ['id' => 'addtoanyfeed', 'name' => 'AddToAny (feed)', 'type' => 'social'],
      ['id' => 'pinterest', 'name' => 'Pinterest', 'type' => 'social'],
      ['id' => 'addtoanyshare', 'name' => 'AddToAny (share)', 'type' => 'social'],
      ['id' => 'twitter', 'name' => 'Twitter', 'type' => 'social'],
      ['id' => 'twitterembed', 'name' => 'Twitter (cards)', 'type' => 'social'],
      ['id' => 'purechat', 'name' => 'PureChat', 'type' => 'support'],
      ['id' => 'zopim', 'name' => 'Zopim', 'type' => 'support'],
      ['id' => 'tawkto', 'name' => 'Tawk.to chat', 'type' => 'support'],
      ['id' => 'uservoice', 'name' => 'UserVoice', 'type' => 'support'],
      ['id' => 'vimeo', 'name' => 'Vimeo', 'type' => 'video'],
      ['id' => 'slideshare', 'name' => 'SlideShare', 'type' => 'video'],
      ['id' => 'youtubeplaylist', 'name' => 'YouTube (playlist)', 'type' => 'video'],
      ['id' => 'prezi', 'name' => 'Prezi', 'type' => 'video'],
      ['id' => 'youtube', 'name' => 'YouTube', 'type' => 'video'],
      ['id' => 'dailymotion', 'name' => 'Dailymotion', 'type' => 'video'],
      ['id' => 'calameo', 'name' => 'Calameo', 'type' => 'video'],
      ['id' => 'youtubeapi', 'name' => 'Youtube (Js API)', 'type' => 'video'],
    ];

    for ($i = 0; $i < count($services); $i++) {
      $form['service'][$services[$i]['type']][$services[$i]['id']] = [
        '#type' => 'checkbox',
        '#title' => $this->t($services[$i]['name']),
        '#default_value' => $config->get('services.' . $services[$i]['id']),
        '#weight' => $i * 10,
      ];
    }

    $users_textfield = [
      ['id' => 'addthisPubId', 'name' => 'Your AddThis profile ID', 'service' => 'addthis', 'type' => 'social'],
      ['id' => 'addtoanyfeedUri', 'name' => 'URL to be shared', 'service' => 'addtoanyfeed', 'type' => 'social'],
      ['id' => 'addtoanyfeedSubscribeLink', 'name' => 'URL to be shared', 'service' => 'addtoanyfeed', 'type' => 'social'],
      ['id' => 'alexaAccountID', 'name' => 'Your Alexa ID', 'service' => 'alexa', 'type' => 'analytic'],
      ['id' => 'clickyId', 'name' => 'Your Clicky ID', 'service' => 'clicky', 'type' => 'analytic'],
      ['id' => 'crazyeggId', 'name' => 'Your Crazy Egg ID', 'service' => 'crazyegg', 'type' => 'analytic'],
      ['id' => 'leadforensicsSf14gv', 'name' => 'Your LeadForensics sf14gv', 'service' => 'leadforensics', 'type' => 'analytic'],
      ['id' => 'leadforensicsIidentifier', 'name' => 'Your LeadForensics identifier', 'service' => 'leadforensics', 'type' => 'analytic'],
      ['id' => 'disqusShortname', 'name' => 'Your Disqus shortname', 'service' => 'disqus', 'type' => 'comment'],
      ['id' => 'ekomiCertId', 'name' => 'Your eKomi ID', 'service' => 'ekomi', 'type' => 'social'],
      ['id' => 'etracker', 'name' => 'Your Account Key 1', 'service' => 'etracker', 'type' => 'analytic'],
      ['id' => 'getplusId', 'name' => 'Your Get+ ID', 'service' => 'getplus', 'type' => 'analytic'],
      ['id' => 'adsensesearchresultCx', 'name' => 'Your custom search engine ID ', 'service' => 'adsensesearchresult', 'type' => 'ads'],
      ['id' => 'adwordsconversionId', 'name' => 'Your Google Adwords ID', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionLabel', 'name' => 'Your Google Adwords label', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionLanguage', 'name' => 'Your Google Adwords language', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionFormat', 'name' => 'Your Google Adwords format', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionColor', 'name' => 'Your Google Adwords color', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionValue', 'name' => 'Your Google Adwords value', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionCurrency', 'name' => 'Your Google Adwords currency', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionCustom1', 'name' => 'Your Google Adwords parameter 1', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsconversionCustom2', 'name' => 'Your Google Adwords parameter 2', 'service' => 'googleadwordsconversion', 'type' => 'ads'],
      ['id' => 'adwordsremarketingId', 'name' => 'Your Conversion ID', 'service' => 'googleadwordsremarketing', 'type' => 'ads'],
      ['id' => 'gajsUa', 'name' => 'Your Tracking ID', 'service' => 'gajs', 'type' => 'analytic'],
      ['id' => 'gajsAnonymizeIp', 'name' => 'Your Google Analytics anonymize Ip', 'service' => 'gajs', 'type' => 'analytic'],
      ['id' => 'analyticsUa', 'name' => 'Your Tracking ID', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'analyticsAnonymizeIp', 'name' => 'Your Google Analytics anonymize Ip', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'analyticsPageView', 'name' => 'Your Google Analytics page view', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'gtagUa', 'name' => 'Your Tracking IDs', 'service' => 'gtag', 'type' => 'analytic'],
      ['id' => 'mapscallback', 'name' => 'Your Google Maps callback function name', 'service' => 'googlemaps', 'type' => 'api'],
      ['id' => 'googlemapsLibraries', 'name' => 'Your Google Maps Libraries', 'service' => 'googlemaps', 'type' => 'api'],
      ['id' => 'googlemapsKey', 'name' => 'Your Google Maps Key', 'service' => 'googlemaps', 'type' => 'api'],
      ['id' => 'googletagmanagerId', 'name' => 'Your Google Tag Manager ID', 'service' => 'googletagmanager', 'type' => 'api'],
      ['id' => 'hubspotId', 'name' => 'Your Hubspot ID', 'service' => 'hubspot', 'type' => 'api'],
      ['id' => 'mauticurl', 'name' => 'Your Mautic JavaScript library Path', 'service' => 'mautic', 'type' => 'api'],
      ['id' => 'microsoftcampaignanalyticsUUID', 'name' => 'Your Microsoft Campaign Analytics UUID', 'service' => 'microsoftcampaignanalytics', 'type' => 'api'],
      ['id' => 'microsoftcampaignanalyticsdomainId', 'name' => 'Your Microsoft Campaign Analytics domain ID', 'service' => 'microsoftcampaignanalytics', 'type' => 'api'],
      ['id' => 'microsoftcampaignanalyticsactionId', 'name' => 'Your Microsoft Campaign Analytics action ID', 'service' => 'microsoftcampaignanalytics', 'type' => 'api'],
      ['id' => 'purechatId', 'name' => 'Your PureChat ID', 'service' => 'purechat', 'type' => 'support'],
      ['id' => 'shareaholicSiteId', 'name' => 'Your Site ID', 'service' => 'shareaholic', 'type' => 'social'],
      ['id' => 'sharethisPublisher', 'name' => 'Your publisher key', 'service' => 'sharethis', 'type' => 'social'],
      ['id' => 'tagcommanderid', 'name' => 'Your TagCommander ID', 'service' => 'tagcommander', 'type' => 'api'],
      ['id' => 'twengaId', 'name' => 'Your Twenga ID', 'service' => 'twenga', 'type' => 'ads'],
      ['id' => 'twengaLocale', 'name' => 'Your Twenga JavaScript library Path', 'service' => 'twenga', 'type' => 'ads'],
      ['id' => 'userVoiceApi', 'name' => 'Your UserVoice JavaScript library Path', 'service' => 'uservoice', 'type' => 'support'],
      ['id' => 'visualrevenueId', 'name' => 'Your VisualRevenue ID', 'service' => 'visualrevenue', 'type' => 'analytic'],
      ['id' => 'xitiId', 'name' => 'Your Site number', 'service' => 'xiti', 'type' => 'analytic'],
      ['id' => 'atLibUrl', 'name' => 'Your AT Internet JavaScript library Path', 'service' => 'atinternet', 'type' => 'analytic'],
      ['id' => 'zopimID', 'name' => 'Your Zopim ID', 'service' => 'zopim', 'type' => 'support'],
      ['id' => 'xiti_smarttagLocalPath', 'name' => 'Your Xiti SmartTag JavaScript library Path', 'service' => 'xiti_smarttag', 'type' => 'analytic'],
      ['id' => 'facebookpixelId', 'name' => 'Your pixel\'s ID', 'service' => 'facebookpixel', 'type' => 'ads'],
      ['id' => 'webmecanikurl', 'name' => 'Your Webmecanik URL', 'service' => 'webmecanik', 'type' => 'analytic'],
      ['id' => 'multiplegtagUa', 'name' => 'Your Google Analytics IDs', 'service' => 'multiplegtag', 'type' => 'analytic'],
      ['id' => 'kobanurl', 'name' => 'Your Koban URL', 'service' => 'koban', 'type' => 'analytic'],
      ['id' => 'kobanapi', 'name' => 'Your Koban API', 'service' => 'koban', 'type' => 'analytic'],
      ['id' => 'matomoId', 'name' => 'Your Matomo ID', 'service' => 'matomo', 'type' => 'analytic'],
      ['id' => 'matomoHost', 'name' => 'Your Matomo URL', 'service' => 'matomo', 'type' => 'analytic'],
      ['id' => 'hotjarId', 'name' => 'Your Hotjar ID', 'service' => 'hotjar', 'type' => 'analytic'],
      ['id' => 'HotjarSv', 'name' => 'Your Hotjar Snippet Version', 'service' => 'hotjar', 'type' => 'analytic'],
      ['id' => 'bingadsTag', 'name' => 'Your Bing Ads Universal Event Tracking Tag', 'service' => 'bingads', 'type' => 'ads'],
      ['id' => 'bingadsID', 'name' => 'Your Bing Ads Universal Event Tracking ID', 'service' => 'bingads', 'type' => 'ads'],
      ['id' => 'bingadsStoreCookies', 'name' => 'Your Bing Ads Universal Event Tracking Cookies', 'service' => 'bingads', 'type' => 'ads'],
      ['id' => 'adformpm', 'name' => 'Tracking setup ID of Adform client', 'service' => 'adform', 'type' => 'ads'],
      ['id' => 'adformpagename', 'name' => 'Name of tracking point', 'service' => 'adform', 'type' => 'ads'],
      ['id' => 'actid', 'name' => 'Your Active Campaign ID', 'service' => 'activecampaign', 'type' => 'ads'],
      ['id' => 'tawktoId', 'name' => 'Your chat ID', 'service' => 'tawkto', 'type' => 'support'],
      ['id' => 'getguanty', 'name' => 'Your Site ID', 'service' => 'getquanty', 'type' => 'analytic'],
      ['id' => 'emolyticsID', 'name' => 'Your Emolytics ID', 'service' => 'emolytics', 'type' => 'analytic'],
    ];

    for ($i = 0; $i < count($users_textfield); $i++) {
      $form['service'][$users_textfield[$i]['type']][$users_textfield[$i]['id']] = [
        '#type' => 'textfield',
        '#title' => $this->t($users_textfield[$i]['name']),
        '#default_value' => $config->get('user.' . $users_textfield[$i]['id']),
        '#states' => [
          'visible' => [
            ':input[name="' . $users_textfield[$i]['service'] . '"]' => ['checked' => TRUE],
          ],
        ],
        '#weight' => array_search($users_textfield[$i]['service'], array_column($services, 'id')) * 10 + 1,
      ];
    }

    $users_textarea = [
      ['id' => 'clickyMore', 'name' => 'Your Clicky function', 'service' => 'clicky', 'type' => 'analytic'],
      ['id' => 'ferankMore', 'name' => 'Your FERank function', 'service' => 'ferank', 'type' => 'analytic'],
      ['id' => 'gajsMore', 'name' => 'Your Google Analytics function', 'service' => 'gajs', 'type' => 'analytic'],
      ['id' => 'analyticsPrepare', 'name' => 'Your Google Analytics prepare function', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'analyticsMore', 'name' => 'Your Google Analytics function', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'analyticsUaCreate', 'name' => 'Your Google Analytics fields values', 'service' => 'analytics', 'type' => 'analytic'],
      ['id' => 'gtagMore', 'name' => 'Your Google Analytics function', 'service' => 'gtag', 'type' => 'analytic'],
      ['id' => 'recaptchaOnLoad', 'name' => 'Your onload callback function', 'service' => 'recaptcha', 'type' => 'api'],
      ['id' => 'wysistat', 'name' => 'Your Wysistat values', 'service' => 'wysistat', 'type' => 'analytic'],
      ['id' => 'xitiMore', 'name' => 'Your Xiti function', 'service' => 'xiti', 'type' => 'analytic'],
      ['id' => 'facebookpixelMore', 'name' => 'Your pixel\'s function', 'service' => 'facebookpixel', 'type' => 'ads'],
    ];

    for ($i = 0; $i < count($users_textarea); $i++) {
      $form['service'][$users_textarea[$i]['type']][$users_textarea[$i]['id']] = [
        '#type' => 'textarea',
        '#title' => $this->t($users_textarea[$i]['name']),
        '#default_value' => $config->get('user.' . $users_textarea[$i]['id']),
        '#states' => [
          'visible' => [
            ':input[name="' . $users_textarea[$i]['service'] . '"]' => ['checked' => TRUE],
          ],
        ],
        '#weight' => array_search($users_textarea[$i]['service'], array_column($services, 'id')) * 10 + 1,
      ];
    }

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('tacjs.settings');

    $services = ['aduptech_ads', 'aduptech_conversion', 'aduptech_retargeting', 'amazon', 'clicmanager', 'criteo', 'datingaffiliation', 'datingaffiliationpopup', 'ferankpub', 'adsense', 'googlepartners', 'adsensesearchform', 'adsensesearchresult', 'googleadwordsconversion', 'googleadwordsremarketing', 'prelinker', 'pubdirecte', 'shareasale', 'twenga', 'vshop', 'facebookpixel', 'bingads', 'adform', 'activecampaign', 'alexa', 'clicky', 'crazyegg', 'leadforensics', 'etracker', 'ferank', 'getplus', 'gajs', 'analytics', 'gtag', 'hubspot', 'mautic', 'microsoftcampaignanalytics', 'statcounter', 'visualrevenue', 'wysistat', 'xiti', 'atinternet', 'xiti_smarttag', 'webmecanik', 'multiplegtag', 'koban', 'matomo', 'hotjar', 'getquanty', 'emolytics', 'googlemaps', 'googlemapssearch', 'googlemapsembed', 'googletagmanager', 'jsapi', 'twitterwidgetsapi', 'recaptcha', 'timelinejs', 'tagcommander', 'typekit', 'disqus', 'facebookcomment', 'iframe', 'issuu', 'matterport', 'addthis', 'addtoanyfeed', 'addtoanyshare', 'ekomi', 'facebook', 'facebooklikebox', 'gplus', 'gplusbadge', 'linkedin', 'pinterest', 'shareaholic', 'sharethis', 'twitter', 'twitterembed', 'twittertimeline', 'purechat', 'uservoice', 'zopim', 'tawkto', 'calameo', 'dailymotion', 'prezi', 'slideshare', 'vimeo', 'youtube', 'youtubeplaylist', 'youtubeapi',];

    foreach ($services as $key) {
      $config->set('services.' . $key, $form_state->getValue($key));
    }

    $users = ['addthisPubId', 'addtoanyfeedUri', 'addtoanyfeedSubscribeLink', 'alexaAccountID', 'clickyId', 'clickyMore', 'crazyeggId', 'leadforensicsSf14gv', 'leadforensicsIidentifier', 'disqusShortname', 'ekomiCertId', 'etracker', 'ferankMore', 'getplusId', 'adsensesearchresultCx', 'adwordsconversionId', 'adwordsconversionLabel', 'adwordsconversionLanguage', 'adwordsconversionFormat', 'adwordsconversionColor', 'adwordsconversionValue', 'adwordsconversionCurrency', 'adwordsconversionCustom1', 'adwordsconversionCustom2', 'adwordsremarketingId', 'gajsUa', 'gajsAnonymizeIp', 'gajsPageView', 'gajsMore', 'analyticsUaCreate', 'analyticsUa', 'analyticsAnonymizeIp', 'analyticsPrepare', 'analyticsPageView', 'analyticsMore', 'gtagUa', 'gtagMore', 'mapscallback', 'googlemapsLibraries', 'googlemapsKey', 'googletagmanagerId', 'hubspotId', 'recaptchaOnLoad', 'mauticurl', 'microsoftcampaignanalyticsUUID', 'microsoftcampaignanalyticsdomainId', 'microsoftcampaignanalyticsactionId', 'purechatId', 'shareaholicSiteId', 'sharethisPublisher', 'tagcommanderid', 'typekitId', 'twengaId', 'twengaLocale', 'userVoiceApi', 'visualrevenueId', 'wysistat', 'xitiId', 'xitiMore', 'atLibUrl', 'atMore', 'zopimID', 'xiti_smarttagLocalPath', 'xiti_smarttagSiteId', 'facebookpixelId', 'facebookpixelMore', 'webmecanikurl', 'multiplegtagUa', 'kobanurl', 'kobanapi', 'matomoId', 'matomoHost', 'hotjarId', 'HotjarSv', 'bingadsTag', 'bingadsID', 'bingadsStoreCookies', 'adformpm', 'adformpagename', 'actid', 'tawktoId', 'getguanty', 'emolyticsID',];

    foreach ($users as $key) {
      $config->set('user.' . $key, $form_state->getValue($key));
    }

    $config->save();

    parent::submitForm($form, $form_state);
  }

}
